@@ -36,10 +36,9 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 #if HAVE_EXEMPI
 #include <exempi/xmp.h>
@@ -100,7 +99,6 @@ struct _EogPropertiesDialogPrivate {
 	GtkWidget      *xmp_keywords_label;
 	GtkWidget      *xmp_creator_label;
 	GtkWidget      *xmp_rights_label;
-	GtkWidget      *xmp_details;
 #endif
 #if HAVE_METADATA
 	GtkWidget      *exif_box;
@@ -113,12 +111,14 @@ static void
 pd_update_general_tab (EogPropertiesDialog *prop_dlg, 
 		       EogImage            *image)
 {
-	gchar *bytes_str, *dir_str, *mime_str, *uri_str;
+	gchar *bytes_str, *dir_str, *uri_str;
 	gchar *width_str, *height_str;
-	const gchar *type_str; 
-	gint width, height, bytes;
-
-	uri_str = eog_image_get_uri_for_display (image);
+	GFile *file;
+	GFileInfo *file_info;
+	const char *mime_str;
+	char *type_str;
+	gint width, height;
+	goffset bytes;
 
 	g_object_set (G_OBJECT (prop_dlg->priv->thumbnail_image),
 		      "pixbuf", eog_image_get_thumbnail (image),
@@ -141,25 +141,36 @@ pd_update_general_tab (EogPropertiesDialog *prop_dlg,
 
 	g_free (height_str);
 	g_free (width_str);
-
-	mime_str = gnome_vfs_get_mime_type (uri_str);
-	type_str = gnome_vfs_mime_get_description (mime_str);
+	
+	file = eog_image_get_file (image);
+	file_info = g_file_query_info (file,
+				       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+				       0, NULL, NULL);
+	if (file_info == NULL) {
+		mime_str = _("Unknown");
+		type_str = g_strdup (_("Unknown"));
+	} else {
+		mime_str = g_file_info_get_content_type (file_info);
+		type_str = g_content_type_get_description (mime_str);
+		g_object_unref (file_info);
+	}
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->type_label), type_str);
 
 	bytes = eog_image_get_bytes (image);
-	bytes_str = gnome_vfs_format_file_size_for_display (bytes);
+	bytes_str = g_format_size_for_display (bytes);
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->bytes_label), bytes_str);
 
+	uri_str = eog_image_get_uri_for_display (image);
 	dir_str = g_path_get_dirname (uri_str);
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->location_label), 
 			    dir_str);
 
-	g_free (uri_str);
-	g_free (mime_str);
+	g_free (type_str);
 	g_free (bytes_str);
 	g_free (dir_str);
+	g_free (uri_str);
 }
 
 #if HAVE_EXIF
@@ -183,6 +194,66 @@ eog_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
 	gtk_label_set_text (GTK_LABEL (w), label_text);
 	g_free (label_text);
 }
+
+static void
+eog_exif_set_focal_length_label (GtkWidget *w, ExifData *exif_data)
+{
+	ExifEntry *entry,*entry35mm;
+	ExifByteOrder byte_order;
+	gfloat f_val = 0.0;
+	gchar *fl_text = NULL,*fl35_text = NULL;
+
+	entry = exif_data_get_entry (exif_data, EXIF_TAG_FOCAL_LENGTH);
+	entry35mm = exif_data_get_entry (exif_data,
+					 EXIF_TAG_FOCAL_LENGTH_IN_35MM_FILM);
+	byte_order = exif_data_get_byte_order (exif_data);
+
+	if (entry && G_LIKELY (entry->format == EXIF_FORMAT_RATIONAL)) {
+		ExifRational value;
+
+		/* Decode value by hand as libexif is not necessarily returning
+		 * it in the format we want it to be.
+		 */
+		value = exif_get_rational (entry->data, byte_order);
+		/* Guard against div by zero */
+		if (G_LIKELY(value.denominator != 0))
+			f_val = (gfloat)value.numerator/
+				(gfloat)value.denominator;
+
+		/* TRANSLATORS: This is the actual focal length used when
+		   the image was taken.*/
+		fl_text = g_strdup_printf (_("%.1f (lens)"), f_val);
+
+	}	
+	if (entry35mm && G_LIKELY (entry35mm->format == EXIF_FORMAT_SHORT)) {
+		ExifShort s_val;
+
+		s_val = exif_get_short (entry35mm->data, byte_order);
+
+		/* Print as float to get a similar look as above. */
+		/* TRANSLATORS: This is the equivalent focal length assuming
+		   a 35mm film camera. */
+		fl35_text = g_strdup_printf(_("%.1f (35mm film)"),(float)s_val);
+	}
+
+	if (fl_text) {
+		if (fl35_text) {
+			gchar *merged_txt;
+
+			merged_txt = g_strconcat (fl35_text,", ", fl_text, NULL);
+			gtk_label_set_text (GTK_LABEL (w), merged_txt);
+			g_free (merged_txt);
+		} else {
+			gtk_label_set_text (GTK_LABEL (w), fl_text);
+		}
+	} else {
+		gtk_label_set_text (GTK_LABEL (w), fl35_text);
+	}
+
+	g_free (fl35_text);
+	g_free (fl_text);
+
+}
 #endif
 
 #if HAVE_EXEMPI
@@ -228,6 +299,7 @@ eog_xmp_set_label (XmpPtr xmp,
 			}
 
 			gtk_label_set_text (GTK_LABEL (w), string->str);
+			g_string_free (string, TRUE);
 		}
 	} else {
 		/* Property was not found */
@@ -289,11 +361,7 @@ pd_update_metadata_tab (EogPropertiesDialog *prop_dlg,
 	eog_exif_set_label (priv->exif_exposure_label,
 			    exif_data, EXIF_TAG_EXPOSURE_TIME);
 
-	eog_exif_set_label (priv->exif_focal_label, 
-			    exif_data, EXIF_TAG_FOCAL_LENGTH);
-
-	eog_exif_set_label (priv->exif_focal_label, 
-			    exif_data, EXIF_TAG_FOCAL_LENGTH);
+	eog_exif_set_focal_length_label (priv->exif_focal_label, exif_data);
 
 	eog_exif_set_label (priv->exif_flash_label,
 			    exif_data, EXIF_TAG_FLASH);
