@@ -36,8 +36,6 @@
  */
 #define IMAGE_VIEW_ZOOM_MULTIPLIER 1.05
 
-#define NO_DEBUG
-
 /* States for automatically adjusting the zoom factor */
 typedef enum {
 	ZOOM_MODE_FIT,		/* Image is fitted to scroll view even if the latter changes size */
@@ -1966,7 +1964,7 @@ eog_scroll_view_class_init (EogScrollViewClass *klass)
 
 	view_signals [SIGNAL_ZOOM_CHANGED] =
 		g_signal_new ("zoom_changed",
-			      G_TYPE_OBJECT,
+			      EOG_TYPE_SCROLL_VIEW,
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EogScrollViewClass, zoom_changed),
 			      NULL, NULL,
@@ -2108,6 +2106,15 @@ eog_scroll_view_set_popup (EogScrollView *view,
 			  G_CALLBACK (view_on_button_press_event_cb), NULL);
 }
 
+void
+eog_scroll_view_set_bg_color (EogScrollView *view,
+			      GdkColor *color)
+{
+	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
+
+	gtk_widget_modify_bg (GTK_WIDGET (view), GTK_STATE_NORMAL, color);
+}
+
 void
 eog_scroll_view_set_scroll_wheel_zoom (EogScrollView *view, 
 				       gboolean       scroll_wheel_zoom)
